@@ -1,6 +1,5 @@
 from dataclasses import dataclass, asdict
 from falcon import HTTPUnauthorized, HTTPForbidden, HTTPNotFound
-
 import hug
 from hug.decorators import wraps
 
@@ -9,6 +8,8 @@ from apphelpers.errors import InvalidSessionError
 from apphelpers.sessions import SessionDBHandler
 from converge import settings
 
+from apphelpers.loggers import api_logger
+
 if settings.get('HONEYBADGER_API_KEY'):
     from honeybadger import Honeybadger
     from honeybadger.utils import filter_dict
@@ -45,6 +46,7 @@ def honeybadger_wrapper(hb):
                     e,
                     context={
                         'func': f.__name__,
+                        'args': args,
                         'kwargs': filter_dict(kw, settings.HB_PARAM_FILTERS)
                     }
                 )
@@ -142,6 +144,10 @@ def setup_context_setter(sessions):
                     session['uid'], session['name'], session['groups'],
                     session['email'], session['mobile'], session['site_groups']
                 )
+                if api_logger:
+                    api_logger.info('{} | {} | {}',
+                                    uid, request.method, request.url)
+
             except InvalidSessionError:
                 pass
 
